from mastercardapicore import *

# import apis resourceconfig
from mastercardspendcontrols.resourceconfig import ResourceConfig


# import apis into api package
from mastercardspendcontrols.alertall import *
from mastercardspendcontrols.alerts import *
from mastercardspendcontrols.amount import *
from mastercardspendcontrols.amountdecline import *
from mastercardspendcontrols.card import *
from mastercardspendcontrols.carddisable import *
from mastercardspendcontrols.channel import *
from mastercardspendcontrols.channeldecline import *
from mastercardspendcontrols.controls import *
from mastercardspendcontrols.crossborder import *
from mastercardspendcontrols.crossborderdecline import *
from mastercardspendcontrols.declineall import *
from mastercardspendcontrols.declines import *
from mastercardspendcontrols.notification import *
from mastercardspendcontrols.verify import *
